#
# spec file for package snphost
#
# Copyright (c) 2024 SUSE LLC
# Copyright (C) 2023 VirTEE
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           snphost
Version:        0.5.0
Release:        2.4
Summary:        A Rust command-line tool for interacting with the AMD Secure Processor
License:        Apache-2.0
Group:          Productivity/Security
URL:            https://github.com/virtee/snphost
Source0:        %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  cargo
BuildRequires:  cargo-packaging
BuildRequires:  openssl-devel
BuildRequires:  rubygem(asciidoctor)
ExclusiveArch:  x86_64

%description
snphost is a command line utility for interacting with the AMD Secure Encrypted Virtualization - Secure Nested Paging (SEV-SNP) host environment (via the /dev/sev device).

%prep
# The number passed to -a (a stands for "after") should be equivalent to the Source tag number
# of the vendor tarball, 1 in this case (from Source1).
%autosetup -a1

%build
%{cargo_build}

%install
%{cargo_install}

%check
%{cargo_test}

%files
%license LICENSE
%doc README.md
%{_bindir}/%{name}

%changelog
* Thu Oct  3 2024 Caleb Crane <caleb.crane@suse.com>
- Spec: Add direct dependency on cargo in addition to cargo-packaging.
    This fixes build errors on 15SP7 where the inherited version of Rust
    is too old
* Fri Sep 13 2024 Caleb Crane (caleb.crane@suse.com)
- Update to version 0.5.0:
  * Update to 0.5.0
  * workflows: Update rust toolchain version to 1.80
  * Update clippy workflow toolchain to use 1.74
  * Update Rust version to 1.7.4
  * Upgrade sev to 4.0.0
  * Remove strict semvar for clap dependency
  * Adding cert fetch support for Turin
  * Update to 0.4.0
  * Update sev to 3.2.0
  * build(deps): bump anyhow from 1.0.82 to 1.0.83 (#51)
  * fix: remove subcommand trait on ok/commit (#53)
  * build(deps): bump libc from 0.2.153 to 0.2.154
  * clap-migration: Moving from StructOpt to Clap (#48)
  * build(deps): bump anyhow from 1.0.81 to 1.0.82 (#47)
  * build(deps): bump anyhow from 1.0.80 to 1.0.81
  * Fixing release to 0.3.0, not ready for 1.0.0
  * Bumping rust minimum version to 1.70
  * modifying docs
  * Added DER and VLEK support
  * Changing commands for new 6.6 kernel IOCTL structure
  * Adding tests to snphostok (#39)
  * Modify workflow to match SEV and use rust 1.70 (#41)
  * Fetch: Adding Bergamo and Siena Support (#31)
  * Adding DCO and auto-assign
  * In vcek url use reported_tcb_version (#29)
  * Add lockfile
  * build(deps): update env_logger requirement from 0.9.0 to 0.10.1
* Mon Jan 22 2024 Caleb Crane (caleb.crane@suse.com)
- Update to version 0.2.0~0:
  * New Release
  * fmt: Fixing project structure (#18)
  * 14: Certificate Formatting (#17)
  * Update docs/snphost.1.adoc
  * PR-fixes: Addressing directory creation need
  * docs: Updating the documentation
  * certs: Adding CA and CRL functionality
  * Auto Assign: Adding yml files
  * reset: Reset SEV-SNP extended config instead of PLATFORM_RESET
- spec: Use rubygem() macro to resolve asciidoctor versions
* Fri Oct 13 2023 larry.j.dewey@gmail.com
- Update to version 0.1.2~0:
  * cargo: Update to 0.1.2
  * ok: Don't take mutable reference to arg
  * build: Don't fail on manpage build error
* Mon Jul 10 2023 Larry Dewey <larry.j.dewey@gmail.com>
- Adding a build requirement conditional flag for 15.5, etc.
* Mon Jul 10 2023 Larry Dewey <larry.j.dewey@gmail.com>
- Initial release of v0.1.1
